@@ -4,24 +4,24 @@ package Return::Value;
 # vi:et:sw=4 ts=4
 
 use vars qw[$VERSION @EXPORT $NO_CLUCK];  ## no critic Export
-$VERSION = '1.666000';
+$VERSION = '1.666002';
 @EXPORT  = qw[success failure];
 
 use base qw[Exporter];
 use Carp ();
 
+Carp::cluck "Return::Value is deprecated" unless $NO_CLUCK;
+
 =head1 NAME
 
 Return::Value - (deprecated) polymorphic return values
 
 =head1 VERSION
 
-version 1.666000
+version 1.666001
 
 =head1 DO NOT USE THIS LIBRARY
 
-B<This library will begin issuing deprecation warnings in June 2010.>
-
 Return::Value was a bad idea.  i'm sorry that I had it, sorry that I followed
 through, and sorry that it got used in other useful libraries.  Fortunately
 there are not many things using it.  One of those things is
@@ -38,6 +38,11 @@ especially when the object has useful properties.
 
 B<Please do not use this library.  You will just regret it later.>
 
+A release of this library in June 2009 promised that deprecation warnings would
+start being issued in June 2010.  It is now December 2012, and the warnings are
+now being issued.  They can be disabled through means made clear from the
+source.
+
 =head1 SYNOPSIS
 
 Used with basic function-call interface:
@@ -228,10 +233,6 @@ object's attributes.
 
 sub new {
     my $class = shift;
-    if (time > 1276012556) { # Tue Jun  8 11:55:56 2010
-        Carp::cluck "Return::Value is deprecated" unless $NO_CLUCK;
-    }
-
     bless { type => 'failure', string => q{}, prop => {}, @_ } => $class;
 }
 
@@ -345,10 +346,6 @@ use overload
 
 =back
 
-=head1 TODO
-
-Add deprecation.
-
 =head1 AUTHORS
 
 Casey West, <F<casey@geeknest.com>>.
